# agci
This is a tutorial on how to debut a PyPI application and how to validate software reproducibility.
This agci is renamed and modified from "Symmetric GC integration.py" at https://github.com/1mikegrn/pyGC/blob/master/JCE-supplemental/Asymmetric%20GC%20integration.py
The modification is used to show how to debut a PyPI application and how to validate software reproducibility 
via Code Ocean.

# how to install agci

$ pip install agci

# how to run agci
The result picture will be saved in result.png.

$ agci "csv data filename"

$ agci Sample\ GC\ data\ 1\ pt\ acetone\ 1\ pt\ cyclohexane.csv

<img src='https://github.com/ytakefuji/agci/raw/main/result.png' width=640 hight=480>
